/*
 * Programming in Java, Jacobs University, 2015
 *
 * This file implements the class Rot13Writer, a FilterWriter that
 * applies rot13 to all letters (a-z,A-Z) passed to it. Note that we
 * do not like to modify the objects passed to the write() methods
 * (and also recall that strings are immutable in Java). The example
 * main() demonstrates how to turn a PrintStream (System.out) into a
 * Writer that we then turn into a Rot13Writer.
 */

import java.io.IOException;
import java.io.Writer;
import java.io.FilterWriter;
import java.io.OutputStreamWriter;
import java.util.Scanner;

public class Rot13Writer extends FilterWriter
{
    public Rot13Writer(Writer out)
    {
	super(out);
    }

    public void write(char[] cbuf, int off, int len)
	throws IOException
    {
	char[] rbuf = new char[cbuf.length];
	
	for (int i = 0; i < cbuf.length; i++) {
	    rbuf[i] = (char) rot13(cbuf[i]);
	}

	out.write(rbuf, off, len);
    }

    public void write(int c)
	throws IOException
    {
	out.write(rot13(c));
    }

    public void write(String str, int off, int len)
	throws IOException
    {
	char[] cbuf = str.toCharArray();

	for (int i = 0; i < cbuf.length; i++) {
	    cbuf[i] = (char) rot13(cbuf[i]);
	}
	
	out.write(new String(cbuf), off, len);
    }

    private int rot13(int c)
    {
	if       (c >= 'a' && c <= 'm') c += 13;
	else if  (c >= 'A' && c <= 'M') c += 13;
	else if  (c >= 'n' && c <= 'z') c -= 13;
	else if  (c >= 'N' && c <= 'Z') c -= 13;
	return c;
    }

    static public void main(String[] args)
	throws IOException
    {
	Writer out = new Rot13Writer(new OutputStreamWriter(System.out));
	Scanner sc = new Scanner(System.in);

	while (sc.hasNextLine()) {
	    String line = sc.nextLine();
	    out.write(line);
	    out.write(System.getProperty("line.separator"));
	    out.flush();
	}
    }
}
